# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/common/v1/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/common/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)insightproto/proto/common/v1/common.proto\x12\x1cinsightproto.proto.common.v1\x1a google/protobuf/descriptor.proto\"0\n\x06Source\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"\x1a\n\x0cOrganisation\x12\n\n\x02id\x18\x01 \x01(\t:-\n\x04tags\x12\x1d.google.protobuf.FieldOptions\x18\xc3\xe0\x33 \x01(\tB1Z/github.com/opentrace/insight-proto-go/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.common.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/opentrace/insight-proto-go/common/v1'
  _globals['_SOURCE']._serialized_start=109
  _globals['_SOURCE']._serialized_end=157
  _globals['_ORGANISATION']._serialized_start=159
  _globals['_ORGANISATION']._serialized_end=185
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/results.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/results.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from insightproto.proto.results.v1 import timeline_details_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_timeline__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+insightproto/proto/results/v1/results.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a\x34insightproto/proto/results/v1/timeline_details.proto\"\xd3\x07\n\x13InvestigationResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12t\n\x10\x61lert_extraction\x18\x03 \x01(\x0b\x32..insightproto.proto.results.v1.AlertExtractionB*\x9a\x84\x9e\x03%firestore:\"alertExtraction,omitempty\"\x12\x63\n\x08timeline\x18\x04 \x03(\x0b\x32,.insightproto.proto.results.v1.TimelineEventB#\x9a\x84\x9e\x03\x1e\x66irestore:\"timeline,omitempty\"\x12\x64\n\nhypotheses\x18\x05 \x03(\x0b\x32).insightproto.proto.results.v1.HypothesisB%\x9a\x84\x9e\x03 firestore:\"hypotheses,omitempty\"\x12\x34\n\x07trigger\x18\x06 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\x12^\n\x08metadata\x18\x07 \x01(\x0b\x32\'.insightproto.proto.results.v1.MetaDataB#\x9a\x84\x9e\x03\x1e\x66irestore:\"metadata,omitempty\"\x12S\n\tcreatedAt\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB$\x9a\x84\x9e\x03\x1f\x66irestore:\"createdAt,omitempty\"\x12S\n\tupdatedAt\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB$\x9a\x84\x9e\x03\x1f\x66irestore:\"updatedAt,omitempty\"\x12Q\n\x08\x63losedAt\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB#\x9a\x84\x9e\x03\x1e\x66irestore:\"closedAt,omitempty\"\x12]\n\x0e\x61gentTimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB)\x9a\x84\x9e\x03$firestore:\"agentTimestamp,omitempty\"\x12\r\n\x05title\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\x12\x0e\n\x06status\x18\x0e \x01(\t\x12\x10\n\x08priority\x18\x0f \x01(\t\"\xbd\x02\n\x08MetaData\x12\x33\n\x05\x61gent\x18\x01 \x01(\x0b\x32$.insightproto.proto.results.v1.Agent\x12-\n\tstartTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\ttoolCalls\x18\x04 \x01(\x05\x12\x18\n\x10phase2Iterations\x18\x05 \x01(\x05\x12\x38\n\x04mcps\x18\x06 \x03(\x0b\x32*.insightproto.proto.results.v1.MCPCategory\x12\x39\n\x06tokens\x18\x07 \x03(\x0b\x32).insightproto.proto.results.v1.TokenUsage\"H\n\nTokenUsage\x12\r\n\x05model\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x03\x12\x0e\n\x06output\x18\x03 \x01(\x03\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x01\"0\n\x0bMCPCategory\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0f\n\x07servers\x18\x02 \x03(\t\"&\n\x05\x41gent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"n\n\x0f\x41lertExtraction\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\"\xde\r\n\rTimelineEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x34\n\x06source\x18\x03 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12k\n\nimportance\x18\x04 \x01(\x0e\x32..insightproto.proto.results.v1.ImportanceLevelB\'\x18\x01\x9a\x84\x9e\x03 firestore:\"importance,omitempty\"\x12\x33\n\x0f\x61gent_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12g\n\nlog_detail\x18\x06 \x01(\x0b\x32(.insightproto.proto.results.v1.LogDetailB$\x9a\x84\x9e\x03\x1f\x66irestore:\"logDetail,omitempty\"H\x00\x88\x01\x01\x12j\n\x0b\x63ode_detail\x18\x07 \x01(\x0b\x32).insightproto.proto.results.v1.CodeDetailB%\x9a\x84\x9e\x03 firestore:\"codeDetail,omitempty\"H\x01\x88\x01\x01\x12\x83\x01\n\x14merge_request_detail\x18\x08 \x01(\x0b\x32\x31.insightproto.proto.results.v1.MergeRequestDetailB-\x9a\x84\x9e\x03(firestore:\"mergeRequestDetail,omitempty\"H\x02\x88\x01\x01\x12\x64\n\tci_detail\x18\t \x01(\x0b\x32\'.insightproto.proto.results.v1.CIDetailB#\x9a\x84\x9e\x03\x1e\x66irestore:\"ciDetail,omitempty\"H\x03\x88\x01\x01\x12y\n\x10knowledge_detail\x18\n \x01(\x0b\x32..insightproto.proto.results.v1.KnowledgeDetailB*\x9a\x84\x9e\x03%firestore:\"knowledgeDetail,omitempty\"H\x04\x88\x01\x01\x12p\n\rticket_detail\x18\x0b \x01(\x0b\x32+.insightproto.proto.results.v1.TicketDetailB\'\x9a\x84\x9e\x03\"firestore:\"ticketDetail,omitempty\"H\x05\x88\x01\x01\x12s\n\x0etrigger_detail\x18\x0c \x01(\x0b\x32,.insightproto.proto.results.v1.TriggerDetailB(\x9a\x84\x9e\x03#firestore:\"triggerDetail,omitempty\"H\x06\x88\x01\x01\x12s\n\x0egeneric_detail\x18\r \x01(\x0b\x32,.insightproto.proto.results.v1.GenericDetailB(\x9a\x84\x9e\x03#firestore:\"genericDetail,omitempty\"H\x07\x88\x01\x01\x12p\n\rmetric_detail\x18\x0e \x01(\x0b\x32+.insightproto.proto.results.v1.MetricDetailB\'\x9a\x84\x9e\x03\"firestore:\"metricDetail,omitempty\"H\x08\x88\x01\x01\x12\r\n\x05query\x18\x0f \x01(\t\x12\n\n\x02id\x18\x10 \x01(\t\x12\x12\n\nhypothesis\x18\x11 \x01(\t\x12^\n\x11importanceMapping\x18\x12 \x03(\x0b\x32\x43.insightproto.proto.results.v1.TimelineEvent.ImportanceMappingEntry\x12\r\n\x05title\x18\x13 \x01(\t\x1ah\n\x16ImportanceMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0e\x32..insightproto.proto.results.v1.ImportanceLevel:\x02\x38\x01\x42\r\n\x0b_log_detailB\x0e\n\x0c_code_detailB\x17\n\x15_merge_request_detailB\x0c\n\n_ci_detailB\x13\n\x11_knowledge_detailB\x10\n\x0e_ticket_detailB\x11\n\x0f_trigger_detailB\x11\n\x0f_generic_detailB\x10\n\x0e_metric_detail\"\x8d\x03\n\nHypothesis\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\r\x12L\n\x13supporting_evidence\x18\x03 \x03(\tB/\x18\x01\x9a\x84\x9e\x03(firestore:\"supportingEvidence,omitempty\"\x12N\n\x14timeline_correlation\x18\x04 \x03(\tB0\x18\x01\x9a\x84\x9e\x03)firestore:\"timelineCorrelation,omitempty\"\x12\x45\n\x0frecommendations\x18\x05 \x03(\tB,\x18\x01\x9a\x84\x9e\x03%firestore:\"recommendations,omitempty\"\x12\r\n\x05title\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x14\n\x0c\x63orrelations\x18\x08 \x03(\t\x12@\n\x0cremediations\x18\t \x03(\x0b\x32*.insightproto.proto.results.v1.Remediation\"R\n\x0bRemediation\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05tasks\x18\x03 \x03(\t\x12\x10\n\x08\x65stimate\x18\x04 \x01(\t*\xa4\x01\n\x0fImportanceLevel\x12 \n\x1cIMPORTANCE_LEVEL_UNSPECIFIED\x10\x00\x12\x18\n\x14IMPORTANCE_LEVEL_LOW\x10\x01\x12\x1b\n\x17IMPORTANCE_LEVEL_MEDIUM\x10\x02\x12\x19\n\x15IMPORTANCE_LEVEL_HIGH\x10\x03\x12\x1d\n\x19IMPORTANCE_LEVEL_CRITICAL\x10\x04\x42\x32Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.results_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['alert_extraction']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['alert_extraction']._serialized_options = b'\232\204\236\003%firestore:\"alertExtraction,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['timeline']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['timeline']._serialized_options = b'\232\204\236\003\036firestore:\"timeline,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['hypotheses']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['hypotheses']._serialized_options = b'\232\204\236\003 firestore:\"hypotheses,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['metadata']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['metadata']._serialized_options = b'\232\204\236\003\036firestore:\"metadata,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['createdAt']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['createdAt']._serialized_options = b'\232\204\236\003\037firestore:\"createdAt,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['updatedAt']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['updatedAt']._serialized_options = b'\232\204\236\003\037firestore:\"updatedAt,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['closedAt']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['closedAt']._serialized_options = b'\232\204\236\003\036firestore:\"closedAt,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['agentTimestamp']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['agentTimestamp']._serialized_options = b'\232\204\236\003$firestore:\"agentTimestamp,omitempty\"'
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._loaded_options = None
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_TIMELINEEVENT'].fields_by_name['importance']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['importance']._serialized_options = b'\030\001\232\204\236\003 firestore:\"importance,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['log_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['log_detail']._serialized_options = b'\232\204\236\003\037firestore:\"logDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['code_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['code_detail']._serialized_options = b'\232\204\236\003 firestore:\"codeDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['merge_request_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['merge_request_detail']._serialized_options = b'\232\204\236\003(firestore:\"mergeRequestDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['ci_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['ci_detail']._serialized_options = b'\232\204\236\003\036firestore:\"ciDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['knowledge_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['knowledge_detail']._serialized_options = b'\232\204\236\003%firestore:\"knowledgeDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['ticket_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['ticket_detail']._serialized_options = b'\232\204\236\003\"firestore:\"ticketDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['trigger_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['trigger_detail']._serialized_options = b'\232\204\236\003#firestore:\"triggerDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['generic_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['generic_detail']._serialized_options = b'\232\204\236\003#firestore:\"genericDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['metric_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['metric_detail']._serialized_options = b'\232\204\236\003\"firestore:\"metricDetail,omitempty\"'
  _globals['_HYPOTHESIS'].fields_by_name['supporting_evidence']._loaded_options = None
  _globals['_HYPOTHESIS'].fields_by_name['supporting_evidence']._serialized_options = b'\030\001\232\204\236\003(firestore:\"supportingEvidence,omitempty\"'
  _globals['_HYPOTHESIS'].fields_by_name['timeline_correlation']._loaded_options = None
  _globals['_HYPOTHESIS'].fields_by_name['timeline_correlation']._serialized_options = b'\030\001\232\204\236\003)firestore:\"timelineCorrelation,omitempty\"'
  _globals['_HYPOTHESIS'].fields_by_name['recommendations']._loaded_options = None
  _globals['_HYPOTHESIS'].fields_by_name['recommendations']._serialized_options = b'\030\001\232\204\236\003%firestore:\"recommendations,omitempty\"'
  _globals['_IMPORTANCELEVEL']._serialized_start=4071
  _globals['_IMPORTANCELEVEL']._serialized_end=4235
  _globals['_INVESTIGATIONRESULT']._serialized_start=248
  _globals['_INVESTIGATIONRESULT']._serialized_end=1227
  _globals['_METADATA']._serialized_start=1230
  _globals['_METADATA']._serialized_end=1547
  _globals['_TOKENUSAGE']._serialized_start=1549
  _globals['_TOKENUSAGE']._serialized_end=1621
  _globals['_MCPCATEGORY']._serialized_start=1623
  _globals['_MCPCATEGORY']._serialized_end=1671
  _globals['_AGENT']._serialized_start=1673
  _globals['_AGENT']._serialized_end=1711
  _globals['_ALERTEXTRACTION']._serialized_start=1713
  _globals['_ALERTEXTRACTION']._serialized_end=1823
  _globals['_TIMELINEEVENT']._serialized_start=1826
  _globals['_TIMELINEEVENT']._serialized_end=3584
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._serialized_start=3315
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._serialized_end=3419
  _globals['_HYPOTHESIS']._serialized_start=3587
  _globals['_HYPOTHESIS']._serialized_end=3984
  _globals['_REMEDIATION']._serialized_start=3986
  _globals['_REMEDIATION']._serialized_end=4068
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/timeline_details.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/timeline_details.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4insightproto/proto/results/v1/timeline_details.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a)insightproto/proto/common/v1/common.proto\"\xc2\x01\n\x08LogEntry\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x43\n\x06labels\x18\x03 \x03(\x0b\x32\x33.insightproto.proto.results.v1.LogEntry.LabelsEntry\x12\r\n\x05level\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x01\n\tLogDetail\x12\x35\n\x04logs\x18\x02 \x03(\x0b\x32\'.insightproto.proto.results.v1.LogEntry\x12\r\n\x05query\x18\x03 \x01(\t\x12-\n\x04text\x18\x04 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x05 \x01(\t\"\xbb\x03\n\x0b\x41nnotations\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x63\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB)\x9a\x84\x9e\x03$firestore:\"startTimestamp,omitempty\"H\x00\x88\x01\x01\x12_\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\'\x9a\x84\x9e\x03\"firestore:\"endTimestamp,omitempty\"H\x01\x88\x01\x01\x12\r\n\x05label\x18\x05 \x01(\t\x12\r\n\x05\x63olor\x18\x06 \x01(\t\x12\x34\n\x05value\x18\x07 \x01(\x02\x42 \x9a\x84\x9e\x03\x1b\x66irestore:\"value,omitempty\"H\x02\x88\x01\x01\x12:\n\ty_axis_id\x18\x08 \x01(\tB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"yAxisId,omitempty\"H\x03\x88\x01\x01\x42\x12\n\x10_start_timestampB\x10\n\x0e_end_timestampB\x08\n\x06_valueB\x0c\n\n_y_axis_id\"\xe1\x01\n\x06Series\x12\x10\n\x08\x64\x61ta_key\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\ty_axis_id\x18\x04 \x01(\t\x12\x14\n\x0cstroke_width\x18\x05 \x01(\x05\x12\r\n\x05\x63olor\x18\x06 \x01(\t\x12\x41\n\x06labels\x18\x07 \x03(\x0b\x32\x31.insightproto.proto.results.v1.Series.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x01\n\nMetricData\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x06values\x18\x02 \x03(\x0b\x32\x35.insightproto.proto.results.v1.MetricData.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x06Layout\x12\x19\n\x11left_x_axis_label\x18\x01 \x01(\t\x12\x1a\n\x12right_y_axis_label\x18\x02 \x01(\t\"\x84\x03\n\x0cMetricDetail\x12\r\n\x05query\x18\x03 \x01(\t\x12-\n\x04text\x18\x06 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12?\n\x0b\x61nnotations\x18\t \x03(\x0b\x32*.insightproto.proto.results.v1.Annotations\x12\x35\n\x06series\x18\n \x03(\x0b\x32%.insightproto.proto.results.v1.Series\x12\x37\n\x04\x64\x61ta\x18\x0b \x03(\x0b\x32).insightproto.proto.results.v1.MetricData\x12]\n\x06layout\x18\x0c \x01(\x0b\x32%.insightproto.proto.results.v1.LayoutB!\x9a\x84\x9e\x03\x1c\x66irestore:\"layout,omitempty\"H\x00\x88\x01\x01\x42\t\n\x07_layout\"1\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\"\x84\x02\n\nCodeDetail\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\x12\x11\n\tfile_type\x18\x04 \x01(\t\x12\x12\n\nline_start\x18\x05 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x07 \x01(\t\x12\x33\n\x06\x61uthor\x18\x08 \x01(\x0b\x32#.insightproto.proto.results.v1.User\x12-\n\x04text\x18\t \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\n \x01(\t\x12\x19\n\x11highlighted_lines\x18\x0b \x03(\x05\"\xa6\x02\n\x12MergeRequestDetail\x12\x33\n\x06\x61uthor\x18\x02 \x01(\x0b\x32#.insightproto.proto.results.v1.User\x12\x36\n\tapprovers\x18\x03 \x03(\x0b\x32#.insightproto.proto.results.v1.User\x12*\n\x06opened\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06merged\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\x06 \x01(\t\x12-\n\x04text\x18\x07 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x08 \x01(\t\"y\n\x08\x43IDetail\x12\x13\n\x0bpipeline_id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x0b\n\x03log\x18\x04 \x01(\t\x12-\n\x04text\x18\x05 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x06 \x01(\t\"N\n\x0fKnowledgeDetail\x12-\n\x04text\x18\x02 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xb5\x01\n\x0cTicketDetail\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x11\n\tticket_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x33\n\x06\x61uthor\x18\x05 \x01(\x0b\x32#.insightproto.proto.results.v1.User\x12-\n\x04text\x18\x06 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x07 \x01(\t\"\xc2\x01\n\rTriggerDetail\x12>\n\x0etrigger_source\x18\x02 \x01(\tB&\x18\x01\x9a\x84\x9e\x03\x1f\x66irestore:\"logDetail,omitempty\"\x12\x34\n\x07trigger\x18\x03 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\x12-\n\x04text\x18\x04 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x05 \x01(\t\"L\n\rGenericDetail\x12-\n\x04text\x18\x02 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x03 \x01(\tB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.timeline_details_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_LOGENTRY_LABELSENTRY']._loaded_options = None
  _globals['_LOGENTRY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_LOGDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['start_timestamp']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['start_timestamp']._serialized_options = b'\232\204\236\003$firestore:\"startTimestamp,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['end_timestamp']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['end_timestamp']._serialized_options = b'\232\204\236\003\"firestore:\"endTimestamp,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['value']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['value']._serialized_options = b'\232\204\236\003\033firestore:\"value,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['y_axis_id']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['y_axis_id']._serialized_options = b'\232\204\236\003\035firestore:\"yAxisId,omitempty\"'
  _globals['_SERIES_LABELSENTRY']._loaded_options = None
  _globals['_SERIES_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_METRICDATA_VALUESENTRY']._loaded_options = None
  _globals['_METRICDATA_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_METRICDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_METRICDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_METRICDETAIL'].fields_by_name['layout']._loaded_options = None
  _globals['_METRICDETAIL'].fields_by_name['layout']._serialized_options = b'\232\204\236\003\034firestore:\"layout,omitempty\"'
  _globals['_CODEDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_CODEDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_MERGEREQUESTDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_MERGEREQUESTDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_CIDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_CIDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_KNOWLEDGEDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_KNOWLEDGEDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_TICKETDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_TICKETDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_TRIGGERDETAIL'].fields_by_name['trigger_source']._loaded_options = None
  _globals['_TRIGGERDETAIL'].fields_by_name['trigger_source']._serialized_options = b'\030\001\232\204\236\003\037firestore:\"logDetail,omitempty\"'
  _globals['_TRIGGERDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_TRIGGERDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_GENERICDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_GENERICDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_LOGENTRY']._serialized_start=203
  _globals['_LOGENTRY']._serialized_end=397
  _globals['_LOGENTRY_LABELSENTRY']._serialized_start=352
  _globals['_LOGENTRY_LABELSENTRY']._serialized_end=397
  _globals['_LOGDETAIL']._serialized_start=400
  _globals['_LOGDETAIL']._serialized_end=542
  _globals['_ANNOTATIONS']._serialized_start=545
  _globals['_ANNOTATIONS']._serialized_end=988
  _globals['_SERIES']._serialized_start=991
  _globals['_SERIES']._serialized_end=1216
  _globals['_SERIES_LABELSENTRY']._serialized_start=352
  _globals['_SERIES_LABELSENTRY']._serialized_end=397
  _globals['_METRICDATA']._serialized_start=1219
  _globals['_METRICDATA']._serialized_end=1389
  _globals['_METRICDATA_VALUESENTRY']._serialized_start=1344
  _globals['_METRICDATA_VALUESENTRY']._serialized_end=1389
  _globals['_LAYOUT']._serialized_start=1391
  _globals['_LAYOUT']._serialized_end=1454
  _globals['_METRICDETAIL']._serialized_start=1457
  _globals['_METRICDETAIL']._serialized_end=1845
  _globals['_USER']._serialized_start=1847
  _globals['_USER']._serialized_end=1896
  _globals['_CODEDETAIL']._serialized_start=1899
  _globals['_CODEDETAIL']._serialized_end=2159
  _globals['_MERGEREQUESTDETAIL']._serialized_start=2162
  _globals['_MERGEREQUESTDETAIL']._serialized_end=2456
  _globals['_CIDETAIL']._serialized_start=2458
  _globals['_CIDETAIL']._serialized_end=2579
  _globals['_KNOWLEDGEDETAIL']._serialized_start=2581
  _globals['_KNOWLEDGEDETAIL']._serialized_end=2659
  _globals['_TICKETDETAIL']._serialized_start=2662
  _globals['_TICKETDETAIL']._serialized_end=2843
  _globals['_TRIGGERDETAIL']._serialized_start=2846
  _globals['_TRIGGERDETAIL']._serialized_end=3040
  _globals['_GENERICDETAIL']._serialized_start=3042
  _globals['_GENERICDETAIL']._serialized_end=3118
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Source(google.protobuf.message.Message):
    """Source is the source of the data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the configured integration"""
    name: builtins.str
    """the name of the integration (e.g. datadog)"""
    type: builtins.str
    """the type of the integration (e.g. logs)"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name", "type", b"type"]) -> None: ...

global___Source = Source

@typing.final
class Organisation(google.protobuf.message.Message):
    """Organisation describes the organisation info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the organisation id"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___Organisation = Organisation

TAGS_FIELD_NUMBER: builtins.int
tags: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
"""Multiple Tags can be specified."""



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import insightproto.proto.common.v1.common_pb2
import insightproto.proto.results.v1.results_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UpdateRequest(google.protobuf.message.Message):
    """UpdateRequest represents an incremental update sent by the agent during
    investigation processing.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVESTIGATION_ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    investigation_id: builtins.str
    """The investigation ID that this update relates to."""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """The organization that owns the investigation."""

    @property
    def event(self) -> insightproto.proto.results.v1.results_pb2.TimelineEvent:
        """The timeline event data for this update."""

    def __init__(
        self,
        *,
        investigation_id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        event: insightproto.proto.results.v1.results_pb2.TimelineEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["event", b"event", "org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["event", b"event", "investigation_id", b"investigation_id", "org", b"org"]) -> None: ...

global___UpdateRequest = UpdateRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class JobMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    AETHER_JOB_FIELD_NUMBER: builtins.int
    INSIGHT_JOB_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """the organisation the job is for"""

    @property
    def aether_job(self) -> global___AetherJob: ...
    @property
    def insight_job(self) -> global___InsightJob: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        aether_job: global___AetherJob | None = ...,
        insight_job: global___InsightJob | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["aether_job", b"aether_job", "insight_job", b"insight_job", "job", b"job", "org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["aether_job", b"aether_job", "id", b"id", "insight_job", b"insight_job", "job", b"job", "org", b"org"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["job", b"job"]) -> typing.Literal["aether_job", "insight_job"] | None: ...

global___JobMessage = JobMessage

@typing.final
class AetherJob(google.protobuf.message.Message):
    """AetherJob describes a job for aether to run e.g. a mr review"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    OPERATIONTYPE_FIELD_NUMBER: builtins.int
    ISSUEID_FIELD_NUMBER: builtins.int
    DISCUSSIONID_FIELD_NUMBER: builtins.int
    MERGEREQUESTID_FIELD_NUMBER: builtins.int
    JOBID_FIELD_NUMBER: builtins.int
    NOTEID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the job"""
    OperationType: builtins.str
    """the type of job (e.g. mr review)"""
    IssueId: builtins.str
    """the issue id if available for this job"""
    DiscussionId: builtins.str
    """the discussion id if available for this job"""
    MergeRequestId: builtins.str
    """the mr id  if available for this job"""
    JobId: builtins.str
    """the job id  if available for this job"""
    NoteId: builtins.str
    """the note id  if available for this job"""
    @property
    def project(self) -> global___ProviderProject:
        """the provider (git) project info for the job"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project: global___ProviderProject | None = ...,
        OperationType: builtins.str = ...,
        IssueId: builtins.str | None = ...,
        DiscussionId: builtins.str | None = ...,
        MergeRequestId: builtins.str | None = ...,
        JobId: builtins.str | None = ...,
        NoteId: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["DiscussionId", b"DiscussionId", "IssueId", b"IssueId", "JobId", b"JobId", "MergeRequestId", b"MergeRequestId", "NoteId", b"NoteId", "_DiscussionId", b"_DiscussionId", "_IssueId", b"_IssueId", "_JobId", b"_JobId", "_MergeRequestId", b"_MergeRequestId", "_NoteId", b"_NoteId", "project", b"project"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["DiscussionId", b"DiscussionId", "IssueId", b"IssueId", "JobId", b"JobId", "MergeRequestId", b"MergeRequestId", "NoteId", b"NoteId", "OperationType", b"OperationType", "_DiscussionId", b"_DiscussionId", "_IssueId", b"_IssueId", "_JobId", b"_JobId", "_MergeRequestId", b"_MergeRequestId", "_NoteId", b"_NoteId", "id", b"id", "project", b"project"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_DiscussionId", b"_DiscussionId"]) -> typing.Literal["DiscussionId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_IssueId", b"_IssueId"]) -> typing.Literal["IssueId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_JobId", b"_JobId"]) -> typing.Literal["JobId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_MergeRequestId", b"_MergeRequestId"]) -> typing.Literal["MergeRequestId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_NoteId", b"_NoteId"]) -> typing.Literal["NoteId"] | None: ...

global___AetherJob = AetherJob

@typing.final
class ProviderProject(google.protobuf.message.Message):
    """ProviderProject describes the remote project source info, e.g. the gitlab project to use"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the provider project id to use in the api calls e.g. the gitlab id"""
    name: builtins.str
    """the name of the project"""
    @property
    def provider(self) -> global___Provider:
        """the provider info"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        provider: global___Provider | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["provider", b"provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name", "provider", b"provider"]) -> None: ...

global___ProviderProject = ProviderProject

@typing.final
class Provider(google.protobuf.message.Message):
    """Provider describes the provider source info e.g. the gitlab integration id so we can look up the tokens"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    GITURL_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the id of the integration used"""
    source: builtins.str
    """the type of the integration (e.g. gitlab/github)"""
    gitUrl: builtins.str
    """the https git url for the project"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        source: builtins.str = ...,
        gitUrl: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gitUrl", b"gitUrl", "id", b"id", "source", b"source"]) -> None: ...

global___Provider = Provider

@typing.final
class InsightJob(google.protobuf.message.Message):
    """InsightJob describes a job for insight to investigate"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the job id"""
    @property
    def trigger(self) -> global___Trigger:
        """the job trigger"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        trigger: global___Trigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "trigger", b"trigger"]) -> None: ...

global___InsightJob = InsightJob

@typing.final
class Trigger(google.protobuf.message.Message):
    """Trigger describes where the job has come from (e.g. slack message)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    REFERENCE_ID_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    text: builtins.str
    """the text to feed as the initial input to the agent"""
    reference_id: builtins.str
    """the reference id (eg slack/teams/etc message id)"""
    @property
    def source(self) -> insightproto.proto.common.v1.common_pb2.Source:
        """the source type e.g. slack"""

    @property
    def author(self) -> global___Author:
        """the author information (name, id, avatar)"""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the trigger (e.g. the time of the slack message)"""

    def __init__(
        self,
        *,
        source: insightproto.proto.common.v1.common_pb2.Source | None = ...,
        text: builtins.str = ...,
        reference_id: builtins.str = ...,
        author: global___Author | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "source", b"source", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "reference_id", b"reference_id", "source", b"source", "text", b"text", "timestamp", b"timestamp"]) -> None: ...

global___Trigger = Trigger

@typing.final
class Author(google.protobuf.message.Message):
    """Author is the person that authored the trigger"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    name: builtins.str
    """display name of the author"""
    id: builtins.str
    """unique identifier for the author"""
    avatar: builtins.str
    """URL to the author's avatar/profile image"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
        avatar: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["avatar", b"avatar", "id", b"id", "name", b"name"]) -> None: ...

global___Author = Author



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import insightproto.proto.jobs.v1.jobs_pb2
import insightproto.proto.results.v1.timeline_details_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ImportanceLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ImportanceLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ImportanceLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    IMPORTANCE_LEVEL_UNSPECIFIED: _ImportanceLevel.ValueType  # 0
    IMPORTANCE_LEVEL_LOW: _ImportanceLevel.ValueType  # 1
    IMPORTANCE_LEVEL_MEDIUM: _ImportanceLevel.ValueType  # 2
    IMPORTANCE_LEVEL_HIGH: _ImportanceLevel.ValueType  # 3
    IMPORTANCE_LEVEL_CRITICAL: _ImportanceLevel.ValueType  # 4

class ImportanceLevel(_ImportanceLevel, metaclass=_ImportanceLevelEnumTypeWrapper):
    """ImportanceLevel defines the importance level of a timeline event"""

IMPORTANCE_LEVEL_UNSPECIFIED: ImportanceLevel.ValueType  # 0
IMPORTANCE_LEVEL_LOW: ImportanceLevel.ValueType  # 1
IMPORTANCE_LEVEL_MEDIUM: ImportanceLevel.ValueType  # 2
IMPORTANCE_LEVEL_HIGH: ImportanceLevel.ValueType  # 3
IMPORTANCE_LEVEL_CRITICAL: ImportanceLevel.ValueType  # 4
global___ImportanceLevel = ImportanceLevel

@typing.final
class InvestigationResult(google.protobuf.message.Message):
    """the result of the investigation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    ALERT_EXTRACTION_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    HYPOTHESES_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    CREATEDAT_FIELD_NUMBER: builtins.int
    UPDATEDAT_FIELD_NUMBER: builtins.int
    CLOSEDAT_FIELD_NUMBER: builtins.int
    AGENTTIMESTAMP_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """the investigation id"""
    title: builtins.str
    """the title to use"""
    description: builtins.str
    """the description"""
    status: builtins.str
    """the investigation status (open/closed/inprogress)"""
    priority: builtins.str
    """the investigation priority (low/medium/high/critical/pending)"""
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """the organisation that this belongs to"""

    @property
    def alert_extraction(self) -> global___AlertExtraction:
        """the summary of the trigger"""

    @property
    def timeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimelineEvent]:
        """the list of collected timeline events"""

    @property
    def hypotheses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Hypothesis]:
        """the produced hypotheses"""

    @property
    def trigger(self) -> insightproto.proto.jobs.v1.jobs_pb2.Trigger:
        """the raw trigger information"""

    @property
    def metadata(self) -> global___MetaData:
        """metadata about the agent run"""

    @property
    def createdAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time this investigation was created"""

    @property
    def updatedAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time this was updated last"""

    @property
    def closedAt(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time this was closed"""

    @property
    def agentTimestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time the agent started processing"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        alert_extraction: global___AlertExtraction | None = ...,
        timeline: collections.abc.Iterable[global___TimelineEvent] | None = ...,
        hypotheses: collections.abc.Iterable[global___Hypothesis] | None = ...,
        trigger: insightproto.proto.jobs.v1.jobs_pb2.Trigger | None = ...,
        metadata: global___MetaData | None = ...,
        createdAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updatedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        closedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        agentTimestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        priority: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agentTimestamp", b"agentTimestamp", "alert_extraction", b"alert_extraction", "closedAt", b"closedAt", "createdAt", b"createdAt", "metadata", b"metadata", "org", b"org", "trigger", b"trigger", "updatedAt", b"updatedAt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agentTimestamp", b"agentTimestamp", "alert_extraction", b"alert_extraction", "closedAt", b"closedAt", "createdAt", b"createdAt", "description", b"description", "hypotheses", b"hypotheses", "id", b"id", "metadata", b"metadata", "org", b"org", "priority", b"priority", "status", b"status", "timeline", b"timeline", "title", b"title", "trigger", b"trigger", "updatedAt", b"updatedAt"]) -> None: ...

global___InvestigationResult = InvestigationResult

@typing.final
class MetaData(google.protobuf.message.Message):
    """MetaData about the agent run"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_FIELD_NUMBER: builtins.int
    STARTTIME_FIELD_NUMBER: builtins.int
    ENDTIME_FIELD_NUMBER: builtins.int
    TOOLCALLS_FIELD_NUMBER: builtins.int
    PHASE2ITERATIONS_FIELD_NUMBER: builtins.int
    MCPS_FIELD_NUMBER: builtins.int
    TOKENS_FIELD_NUMBER: builtins.int
    toolCalls: builtins.int
    """the number of tool calls"""
    phase2Iterations: builtins.int
    """the number of phase2 iterations"""
    @property
    def agent(self) -> global___Agent:
        """the info about the agent used"""

    @property
    def startTime(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time the agent started"""

    @property
    def endTime(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time we finished"""

    @property
    def mcps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MCPCategory]:
        """the mcp configs"""

    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TokenUsage]:
        """tokens usage data"""

    def __init__(
        self,
        *,
        agent: global___Agent | None = ...,
        startTime: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        endTime: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        toolCalls: builtins.int = ...,
        phase2Iterations: builtins.int = ...,
        mcps: collections.abc.Iterable[global___MCPCategory] | None = ...,
        tokens: collections.abc.Iterable[global___TokenUsage] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agent", b"agent", "endTime", b"endTime", "startTime", b"startTime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent", b"agent", "endTime", b"endTime", "mcps", b"mcps", "phase2Iterations", b"phase2Iterations", "startTime", b"startTime", "tokens", b"tokens", "toolCalls", b"toolCalls"]) -> None: ...

global___MetaData = MetaData

@typing.final
class TokenUsage(google.protobuf.message.Message):
    """TokenUsage stats per model"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    model: builtins.str
    """the model used"""
    input: builtins.int
    """the input tokens used"""
    output: builtins.int
    """the output tokens used"""
    cost: builtins.float
    """the cost estimate in USD"""
    def __init__(
        self,
        *,
        model: builtins.str = ...,
        input: builtins.int = ...,
        output: builtins.int = ...,
        cost: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "input", b"input", "model", b"model", "output", b"output"]) -> None: ...

global___TokenUsage = TokenUsage

@typing.final
class MCPCategory(google.protobuf.message.Message):
    """MCPCategory config"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORY_FIELD_NUMBER: builtins.int
    SERVERS_FIELD_NUMBER: builtins.int
    category: builtins.str
    """the category name (e.g. logs)"""
    @property
    def servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """the list of servers available for this category"""

    def __init__(
        self,
        *,
        category: builtins.str = ...,
        servers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "servers", b"servers"]) -> None: ...

global___MCPCategory = MCPCategory

@typing.final
class Agent(google.protobuf.message.Message):
    """Agent meta data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """the name of the agent used"""
    version: builtins.str
    """the version string for the agent"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "version", b"version"]) -> None: ...

global___Agent = Agent

@typing.final
class AlertExtraction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    title: builtins.str
    summary: builtins.str
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        title: builtins.str = ...,
        summary: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["summary", b"summary", "tags", b"tags", "timestamp", b"timestamp", "title", b"title"]) -> None: ...

global___AlertExtraction = AlertExtraction

@typing.final
class TimelineEvent(google.protobuf.message.Message):
    """TimelineEvent represents a single event in the investigation timeline"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ImportanceMappingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: global___ImportanceLevel.ValueType
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___ImportanceLevel.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    IMPORTANCE_FIELD_NUMBER: builtins.int
    AGENT_TIMESTAMP_FIELD_NUMBER: builtins.int
    LOG_DETAIL_FIELD_NUMBER: builtins.int
    CODE_DETAIL_FIELD_NUMBER: builtins.int
    MERGE_REQUEST_DETAIL_FIELD_NUMBER: builtins.int
    CI_DETAIL_FIELD_NUMBER: builtins.int
    KNOWLEDGE_DETAIL_FIELD_NUMBER: builtins.int
    TICKET_DETAIL_FIELD_NUMBER: builtins.int
    TRIGGER_DETAIL_FIELD_NUMBER: builtins.int
    GENERIC_DETAIL_FIELD_NUMBER: builtins.int
    METRIC_DETAIL_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    HYPOTHESIS_FIELD_NUMBER: builtins.int
    IMPORTANCEMAPPING_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    summary: builtins.str
    """the summary description of the data collected"""
    importance: global___ImportanceLevel.ValueType
    """how important this data is to the hypothesis
    Deprecated: see importanceMapping
    """
    query: builtins.str
    """the query used to collect the data - this should be the logical query e.g. Get the logs for service..."""
    id: builtins.str
    """the id of the event used for updates"""
    hypothesis: builtins.str
    """the id of the hypothesis that was active when we collected this data"""
    title: builtins.str
    """the display title to use for this event"""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the data (e.g. the earliest log line captured)"""

    @property
    def source(self) -> insightproto.proto.common.v1.common_pb2.Source:
        """the source of the data (e.g. Grafana)"""

    @property
    def agent_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time stamp the agent collected this data"""

    @property
    def log_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.LogDetail:
        """we dont use one_of as this makes the serialisation much more complex"""

    @property
    def code_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.CodeDetail: ...
    @property
    def merge_request_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.MergeRequestDetail: ...
    @property
    def ci_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.CIDetail: ...
    @property
    def knowledge_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.KnowledgeDetail: ...
    @property
    def ticket_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.TicketDetail: ...
    @property
    def trigger_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.TriggerDetail: ...
    @property
    def generic_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.GenericDetail: ...
    @property
    def metric_detail(self) -> insightproto.proto.results.v1.timeline_details_pb2.MetricDetail: ...
    @property
    def importanceMapping(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___ImportanceLevel.ValueType]:
        """the importance level of this data for each hypothesis id"""

    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        summary: builtins.str = ...,
        source: insightproto.proto.common.v1.common_pb2.Source | None = ...,
        importance: global___ImportanceLevel.ValueType = ...,
        agent_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        log_detail: insightproto.proto.results.v1.timeline_details_pb2.LogDetail | None = ...,
        code_detail: insightproto.proto.results.v1.timeline_details_pb2.CodeDetail | None = ...,
        merge_request_detail: insightproto.proto.results.v1.timeline_details_pb2.MergeRequestDetail | None = ...,
        ci_detail: insightproto.proto.results.v1.timeline_details_pb2.CIDetail | None = ...,
        knowledge_detail: insightproto.proto.results.v1.timeline_details_pb2.KnowledgeDetail | None = ...,
        ticket_detail: insightproto.proto.results.v1.timeline_details_pb2.TicketDetail | None = ...,
        trigger_detail: insightproto.proto.results.v1.timeline_details_pb2.TriggerDetail | None = ...,
        generic_detail: insightproto.proto.results.v1.timeline_details_pb2.GenericDetail | None = ...,
        metric_detail: insightproto.proto.results.v1.timeline_details_pb2.MetricDetail | None = ...,
        query: builtins.str = ...,
        id: builtins.str = ...,
        hypothesis: builtins.str = ...,
        importanceMapping: collections.abc.Mapping[builtins.str, global___ImportanceLevel.ValueType] | None = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_ci_detail", b"_ci_detail", "_code_detail", b"_code_detail", "_generic_detail", b"_generic_detail", "_knowledge_detail", b"_knowledge_detail", "_log_detail", b"_log_detail", "_merge_request_detail", b"_merge_request_detail", "_metric_detail", b"_metric_detail", "_ticket_detail", b"_ticket_detail", "_trigger_detail", b"_trigger_detail", "agent_timestamp", b"agent_timestamp", "ci_detail", b"ci_detail", "code_detail", b"code_detail", "generic_detail", b"generic_detail", "knowledge_detail", b"knowledge_detail", "log_detail", b"log_detail", "merge_request_detail", b"merge_request_detail", "metric_detail", b"metric_detail", "source", b"source", "ticket_detail", b"ticket_detail", "timestamp", b"timestamp", "trigger_detail", b"trigger_detail"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_ci_detail", b"_ci_detail", "_code_detail", b"_code_detail", "_generic_detail", b"_generic_detail", "_knowledge_detail", b"_knowledge_detail", "_log_detail", b"_log_detail", "_merge_request_detail", b"_merge_request_detail", "_metric_detail", b"_metric_detail", "_ticket_detail", b"_ticket_detail", "_trigger_detail", b"_trigger_detail", "agent_timestamp", b"agent_timestamp", "ci_detail", b"ci_detail", "code_detail", b"code_detail", "generic_detail", b"generic_detail", "hypothesis", b"hypothesis", "id", b"id", "importance", b"importance", "importanceMapping", b"importanceMapping", "knowledge_detail", b"knowledge_detail", "log_detail", b"log_detail", "merge_request_detail", b"merge_request_detail", "metric_detail", b"metric_detail", "query", b"query", "source", b"source", "summary", b"summary", "ticket_detail", b"ticket_detail", "timestamp", b"timestamp", "title", b"title", "trigger_detail", b"trigger_detail"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_ci_detail", b"_ci_detail"]) -> typing.Literal["ci_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_code_detail", b"_code_detail"]) -> typing.Literal["code_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_generic_detail", b"_generic_detail"]) -> typing.Literal["generic_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_knowledge_detail", b"_knowledge_detail"]) -> typing.Literal["knowledge_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_log_detail", b"_log_detail"]) -> typing.Literal["log_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_merge_request_detail", b"_merge_request_detail"]) -> typing.Literal["merge_request_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_metric_detail", b"_metric_detail"]) -> typing.Literal["metric_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_ticket_detail", b"_ticket_detail"]) -> typing.Literal["ticket_detail"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_trigger_detail", b"_trigger_detail"]) -> typing.Literal["trigger_detail"] | None: ...

global___TimelineEvent = TimelineEvent

@typing.final
class Hypothesis(google.protobuf.message.Message):
    """Hypothesis is an estimated cause of the issue we are investigating"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    SUPPORTING_EVIDENCE_FIELD_NUMBER: builtins.int
    TIMELINE_CORRELATION_FIELD_NUMBER: builtins.int
    RECOMMENDATIONS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CORRELATIONS_FIELD_NUMBER: builtins.int
    REMEDIATIONS_FIELD_NUMBER: builtins.int
    description: builtins.str
    """the description of the hypothesis"""
    confidence: builtins.int
    """the level (0-100) of how confident we are this is the cause"""
    title: builtins.str
    """the hypothesis title"""
    id: builtins.str
    """the id of the hypothesis"""
    @property
    def supporting_evidence(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """this is the summary of the supporting evidence
        Deprecated: see correlations
        """

    @property
    def timeline_correlation(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Deprecated: see correlations"""

    @property
    def recommendations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """the recommended actions to take
        Deprecated: see remediations
        """

    @property
    def correlations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """a list of timeline events"""

    @property
    def remediations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Remediation]:
        """a list of possible remediation tasks"""

    def __init__(
        self,
        *,
        description: builtins.str = ...,
        confidence: builtins.int = ...,
        supporting_evidence: collections.abc.Iterable[builtins.str] | None = ...,
        timeline_correlation: collections.abc.Iterable[builtins.str] | None = ...,
        recommendations: collections.abc.Iterable[builtins.str] | None = ...,
        title: builtins.str = ...,
        id: builtins.str = ...,
        correlations: collections.abc.Iterable[builtins.str] | None = ...,
        remediations: collections.abc.Iterable[global___Remediation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "correlations", b"correlations", "description", b"description", "id", b"id", "recommendations", b"recommendations", "remediations", b"remediations", "supporting_evidence", b"supporting_evidence", "timeline_correlation", b"timeline_correlation", "title", b"title"]) -> None: ...

global___Hypothesis = Hypothesis

@typing.final
class Remediation(google.protobuf.message.Message):
    """Remediation describes a task to help prevent or improve the situation that causes this investigation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    ESTIMATE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """the title of this remediation (e.g. OP-123 Add additional logging when deleting a team member)"""
    description: builtins.str
    """the description of this remediation (e.g. We need to gather more information about what happened...)"""
    estimate: builtins.str
    """an estimate of the clock time required (e.g. 1 day)"""
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """a list of tasks that describe in more detail the actions required
        e.g. add a log line that details the user that is being removed, and who is deleting the user
        """

    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        tasks: collections.abc.Iterable[builtins.str] | None = ...,
        estimate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "estimate", b"estimate", "tasks", b"tasks", "title", b"title"]) -> None: ...

global___Remediation = Remediation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/updates.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/updates.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.results.v1 import results_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+insightproto/proto/results/v1/updates.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a)insightproto/proto/common/v1/common.proto\x1a+insightproto/proto/results/v1/results.proto\"\x9f\x01\n\rUpdateRequest\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12;\n\x05\x65vent\x18\x03 \x01(\x0b\x32,.insightproto.proto.results.v1.TimelineEvent2h\n\rUpdateService\x12W\n\rStreamUpdates\x12,.insightproto.proto.results.v1.UpdateRequest\x1a\x16.google.protobuf.Empty(\x01\x42\x32Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.updates_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_UPDATEREQUEST']._serialized_start=196
  _globals['_UPDATEREQUEST']._serialized_end=355
  _globals['_UPDATESERVICE']._serialized_start=357
  _globals['_UPDATESERVICE']._serialized_end=461
# @@protoc_insertion_point(module_scope)
